@@ -22,6 +22,7 @@ from openstack.cluster.v1 import policy_type as _policy_type
 from openstack.cluster.v1 import profile as _profile
 from openstack.cluster.v1 import profile_type as _profile_type
 from openstack.cluster.v1 import receiver as _receiver
+from openstack.cluster.v1 import service as _service
 from openstack import proxy2
 from openstack import resource2
 from openstack import utils
@@ -899,6 +900,18 @@ class Proxy(proxy2.BaseProxy):
         """
         return self._create(_receiver.Receiver, **attrs)
 
+    def update_receiver(self, receiver, **attrs):
+        """Update a receiver.
+
+        :param receiver: The value can be either the name or ID of a receiver
+            or a :class:`~openstack.cluster.v1.receiver.Receiver` instance.
+        :param attrs: The attributes to update on the receiver parameter.
+            Valid attribute names include ``name``, ``action`` and ``params``.
+        :returns: The updated receiver.
+        :rtype: :class:`~openstack.cluster.v1.receiver.Receiver`
+        """
+        return self._update(_receiver.Receiver, receiver, **attrs)
+
     def delete_receiver(self, receiver, ignore_missing=True):
         """Delete a receiver.
 
@@ -1083,3 +1096,11 @@ class Proxy(proxy2.BaseProxy):
         """
         return resource2.wait_for_delete(self._session, resource, interval,
                                          wait)
+
+    def services(self, **query):
+        """Get a generator of service.
+
+        :returns: A generator of objects that are of type
+                  :class:`~openstack.cluster.v1.service.Service`
+        """
+        return self._list(_service.Service, paginated=False, **query)
