@@ -16,14 +16,13 @@ from openstack.tests.functional import base
 class TestQuota(base.BaseFunctionalTest):
 
     def test_list(self):
-        sot = self.conn.network.quotas()
-        for qot in sot:
-            self.assertIn('subnet', qot)
-            self.assertIn('network', qot)
-            self.assertIn('router', qot)
-            self.assertIn('port', qot)
-            self.assertIn('floatingip', qot)
-            self.assertIn('security_group_rule', qot)
-            self.assertIn('security_group', qot)
-            self.assertIn('subnetpool', qot)
-            self.assertIn('rbac_policy', qot)
+        for qot in self.conn.network.quotas():
+            self.assertIsNotNone(qot.project_id)
+            self.assertIsNotNone(qot.networks)
+
+    def test_set(self):
+        attrs = {'networks': 123456789}
+        for project_quota in self.conn.network.quotas():
+            self.conn.network.update_quota(project_quota, **attrs)
+            new_quota = self.conn.network.get_quota(project_quota.project_id)
+            self.assertEqual(123456789, new_quota.networks)
